==> haskell-genvalidity-property-1.0.0.0-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-HtzwSK0JiW9DQqBCO8F2wW
key:                  genvalidity-property-1.0.0.0-HtzwSK0JiW9DQqBCO8F2wW
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  7f803b3dcada6fdf181dbb8b190fd62d
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-HtzwSK0JiW9DQqBCO8F2wW
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD base-4.17.2.1
    genvalidity-1.1.0.0-ATgqJzWKFmVJBm4tSLaUXp
    hspec-2.10.9-2QQi0gYhs9C6V2MzXjeexi
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
    validity-0.12.0.2-4K97vG29PSs1qkxiF4QBIi

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-1.0.0.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-property
version:              1.0.0.0
visibility:           public
id:                   genvalidity-property-1.0.0.0-FNgEStJHSN77JC1PBU9UPd
key:                  genvalidity-property-1.0.0.0-FNgEStJHSN77JC1PBU9UPd
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
category:             Testing
abi:                  74945e51963f6f1c942d331b960979ba
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-property-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-property
hs-libraries:         HSgenvalidity-property-1.0.0.0-FNgEStJHSN77JC1PBU9UPd
depends:
    QuickCheck-2.14.3-3CoFGl7CagbATKlXLaYDNP base-4.17.2.1
    genvalidity-1.1.1.0-KNvz7EhGHWpDXAClafvjW
    hspec-2.10.9-KjMOU4OB4qFAiRTApzpdJt
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD
    validity-0.12.1.0-2Vn9kStbpg1V7zzyUaLHF

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
